@@ -23,6 +23,7 @@ import org.kuali.rice.core.api.exception.RiceRuntimeException;
 import org.kuali.rice.core.api.resourceloader.GlobalResourceLoader;
 import org.kuali.rice.core.api.uif.RemotableAttributeError;
 import org.kuali.rice.core.api.uif.RemotableAttributeErrorContract;
+import org.kuali.rice.core.api.util.io.SerializationUtils;
 import org.kuali.rice.coreservice.framework.CoreFrameworkServiceLocator;
 import org.kuali.rice.kew.actionitem.ActionItem;
 import org.kuali.rice.kew.actionrequest.ActionRequestValue;
@@ -76,7 +77,6 @@ import org.kuali.rice.kew.service.KEWServiceLocator;
 import org.kuali.rice.kim.api.identity.principal.Principal;
 import org.kuali.rice.kim.api.services.KimApiServiceLocator;
 import org.kuali.rice.krad.util.KRADConstants;
-import org.kuali.rice.krad.util.ObjectUtils;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -222,7 +222,7 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
         if (LOG.isDebugEnabled()) {
             LOG.debug("Initializing Document from incoming documentId: " + documentId);
         }
-        KEWServiceLocator.getRouteHeaderService().lockRouteHeader(documentId, true);
+        KEWServiceLocator.getRouteHeaderService().lockRouteHeader(documentId);
 
         DocumentRouteHeaderValue document = KEWServiceLocator.getRouteHeaderService().getRouteHeader(documentId);
         if (document == null) {
@@ -241,7 +241,7 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
         }
 
         if (modified) {
-            KEWServiceLocator.getRouteHeaderService().saveRouteHeader(document);
+            document = KEWServiceLocator.getRouteHeaderService().saveRouteHeader(document);
 
             /* 
              * Branch data is not persisted when we call saveRouteHeader so we must Explicitly
@@ -270,12 +270,15 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
     private void saveRouteNodeInstances(DocumentRouteHeaderValue routeHeader) {
 
         List<RouteNodeInstance> routeNodes = routeHeader.getInitialRouteNodeInstances();
+        List<RouteNodeInstance> persistedRouteNodes = new ArrayList<RouteNodeInstance>();
+        RouteNodeInstance persistedRni = null;
         if (routeNodes != null && !routeNodes.isEmpty()) {
             for (RouteNodeInstance rni : routeNodes) {
-                KEWServiceLocator.getRouteNodeService().save(rni);
+                persistedRni = KEWServiceLocator.getRouteNodeService().save(rni);
+                persistedRouteNodes.add(persistedRni);
             }
         }
-
+        routeHeader.setInitialRouteNodeInstances(persistedRouteNodes);
     }
 
     @Override
@@ -337,6 +340,27 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
         return KEWServiceLocator.getActionRegistry().getValidActions(principal, documentBo);
     }
 
+    @Override
+    public boolean isValidAction(String actionTypeCode, String documentId, String principalId)
+            throws RiceIllegalArgumentException {
+        incomingParamCheck(actionTypeCode, "actionTypeCode");
+        incomingParamCheck(documentId, "documentId");
+        incomingParamCheck(principalId, "principalId");
+
+        DocumentRouteHeaderValue documentBo = KEWServiceLocator.getRouteHeaderService().getRouteHeader(documentId);
+        if (documentBo == null) {
+            throw new RiceIllegalArgumentException("Failed to locate a document for document id: " + documentId);
+        }
+
+        return determineValidActionInternal(actionTypeCode, documentBo, principalId);
+    }
+
+    protected boolean determineValidActionInternal(String actionTypeCode, DocumentRouteHeaderValue documentBo,
+            String principalId) {
+        Principal principal = KEWServiceLocator.getIdentityHelperService().getPrincipal(principalId);
+        return KEWServiceLocator.getActionRegistry().isValidAction(actionTypeCode, principal, documentBo);
+    }
+
     @Override
     public RequestedActions determineRequestedActions(String documentId, String principalId) {
         incomingParamCheck(documentId, "documentId");
@@ -1162,28 +1186,30 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
         // Deep-copy the action requests for the simulation.
         List<ActionRequestValue> copiedRequests = new ArrayList<ActionRequestValue>();
         for (ActionRequestValue request : requests) {
-        	ActionRequestValue actionRequest = (ActionRequestValue) ObjectUtils.deepCopy(
+        	ActionRequestValue actionRequest = (ActionRequestValue) SerializationUtils.deepCopy(
                     (ActionRequestValue) request);
         	// Deep-copy the action items as well, since they are indirectly retrieved from the action request via service calls.
         	for (ActionItem actionItem : actionRequest.getActionItems()) {
-        		actionRequest.getSimulatedActionItems().add((ActionItem) ObjectUtils.deepCopy(actionItem));
+        		actionRequest.getSimulatedActionItems().add((ActionItem) SerializationUtils.deepCopy(actionItem));
         	}
         	copiedRequests.add(actionRequest);
         }
 
+        List<ActionRequestValue> savedRequests = new ArrayList<ActionRequestValue>();
         ActivationContext activationContext = new ActivationContext(ActivationContext.CONTEXT_IS_SIMULATION);
         for (ActionRequestValue request : copiedRequests) {
             if (activateFirst.booleanValue() && !request.isActive()) {
-                KEWServiceLocator.getActionRequestService().activateRequest(request, activationContext);
+                request = KEWServiceLocator.getActionRequestService().activateRequest(request, activationContext);
             }
             if (request.isUserRequest() && request.getPrincipalId().equals(principalId)) {
-                KEWServiceLocator.getActionRequestService().deactivateRequest(null, request, activationContext);
+                request = KEWServiceLocator.getActionRequestService().deactivateRequest(null, request, activationContext);
             } else if (request.isGroupRequest() && KimApiServiceLocator.getGroupService().isMemberOfGroup(principalId, request.getGroup().getId())) {
-                KEWServiceLocator.getActionRequestService().deactivateRequest(null, request, activationContext);
+                request = KEWServiceLocator.getActionRequestService().deactivateRequest(null, request, activationContext);
             }
+            savedRequests.add(request);
         }
         boolean allDeactivated = true;
-        for (ActionRequestValue actionRequest: copiedRequests) {
+        for (ActionRequestValue actionRequest: savedRequests) {
             allDeactivated = allDeactivated && actionRequest.isDeactivated();
         }
         return allDeactivated;
@@ -1212,7 +1238,7 @@ public class WorkflowDocumentActionsServiceImpl implements WorkflowDocumentActio
         if (principal == null) {
             throw new IllegalArgumentException("Principal for principalId: " + principalId + " does not exist");
         }
-        List<ActionTakenValue> actionsTaken = KEWServiceLocator.getActionTakenService().findByDocumentIdWorkflowId(documentId, principal.getPrincipalId());
+        List<ActionTakenValue> actionsTaken = KEWServiceLocator.getActionTakenService().findByDocumentIdPrincipalId(documentId, principal.getPrincipalId());
 
         if(routeHeader.getInitiatorWorkflowId().equals(principal.getPrincipalId())){
         	return true;
