@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2013 The Kuali Foundation
+ * Copyright 2005-2014 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,25 +15,22 @@
  */
 package org.kuali.rice.kew.engine;
 
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-
-import java.util.Collection;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Set;
-
 import org.junit.Test;
 import org.kuali.rice.kew.actionrequest.ActionRequestValue;
+import org.kuali.rice.kew.api.KewApiConstants;
 import org.kuali.rice.kew.api.WorkflowDocument;
 import org.kuali.rice.kew.api.WorkflowDocumentFactory;
 import org.kuali.rice.kew.api.action.ActionRequestStatus;
 import org.kuali.rice.kew.engine.node.RouteNodeInstance;
 import org.kuali.rice.kew.service.KEWServiceLocator;
 import org.kuali.rice.kew.test.KEWTestCase;
-import org.kuali.rice.kew.api.KewApiConstants;
+
+import java.util.Collection;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Set;
+
+import static org.junit.Assert.*;
 
 public class ParallelRoutingTest extends KEWTestCase {
     
@@ -55,16 +52,16 @@ public class ParallelRoutingTest extends KEWTestCase {
         document.saveDocumentData();
         assertTrue("Document should be initiated", document.isInitiated());
         assertEquals("Should be no action requests.", 0, document.getRootActionRequests().size());
-        Collection nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
+        Collection<RouteNodeInstance> nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
         assertEquals("Wrong number of active nodes.", 1, nodeInstances.size());
         document.route("Routing for parallel");
         
         // should have generated a request to "bmcgough"
         document = WorkflowDocumentFactory.loadDocument(getPrincipalIdForName("bmcgough"), document.getDocumentId());
         assertTrue("Document should be enroute", document.isEnroute());
-        List actionRequests = KEWServiceLocator.getActionRequestService().findPendingByDoc(document.getDocumentId());
+        List<ActionRequestValue> actionRequests = KEWServiceLocator.getActionRequestService().findPendingByDoc(document.getDocumentId());
         assertEquals("Incorrect pending action requests.", 1, actionRequests.size());
-        ActionRequestValue bRequest = (ActionRequestValue)actionRequests.get(0);
+        ActionRequestValue bRequest = actionRequests.get(0);
         assertNotNull("Should have been routed through node instance.", bRequest.getNodeInstance());
         assertTrue(document.isApprovalRequested());
         
@@ -123,7 +120,7 @@ public class ParallelRoutingTest extends KEWTestCase {
         assertTrue("Not at node3.", isNode3);
         nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
         assertEquals("Wrong number of active nodes.", 2, nodeInstances.size());
-        Iterator iterator = nodeInstances.iterator();
+        Iterator<RouteNodeInstance> iterator = nodeInstances.iterator();
         RouteNodeInstance instance1 = (RouteNodeInstance)iterator.next();
         RouteNodeInstance instance2 = (RouteNodeInstance)iterator.next();
         assertNotNull("Node should be in branch.", instance1.getBranch());
@@ -133,13 +130,12 @@ public class ParallelRoutingTest extends KEWTestCase {
         document = WorkflowDocumentFactory.loadDocument(getPrincipalIdForName("rkirkend"), document.getDocumentId());
         assertTrue("Should have request.", document.isApprovalRequested());
         document.approve("Git-r-dun");
-        
+
         nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
         assertEquals("Wrong number of active nodes.", 2, nodeInstances.size());
         boolean isAtJoin = false;
         boolean isAtWD3 = false;
-        for (Iterator iter = nodeInstances.iterator(); iter.hasNext();) {
-            RouteNodeInstance nodeInstance = (RouteNodeInstance) iter.next();
+        for (RouteNodeInstance nodeInstance : nodeInstances) {
             if (nodeInstance.getRouteNode().getRouteNodeName().equals(JOIN_NODE)) {
                 assertEquals("Join branch should be split branch.", instance1.getBranch().getParentBranch().getBranchId(), nodeInstance.getBranch().getBranchId());
                 isAtJoin = true;
@@ -158,8 +154,7 @@ public class ParallelRoutingTest extends KEWTestCase {
         nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
         assertEquals("Wrong number of active nodes.", 1, nodeInstances.size());
         boolean isAtWDF = false;
-        for (Iterator iter = nodeInstances.iterator(); iter.hasNext();) {
-            RouteNodeInstance nodeInstance = (RouteNodeInstance) iter.next();
+        for (RouteNodeInstance nodeInstance : nodeInstances) {
             if (nodeInstance.getRouteNode().getRouteNodeName().equals(WORKFLOW_DOCUMENT_FINAL_NODE)) {
                 isAtWDF = true;
             }
@@ -173,17 +168,8 @@ public class ParallelRoutingTest extends KEWTestCase {
         
         assertTrue("Document should be processed.", document.isProcessed());
         nodeInstances = KEWServiceLocator.getRouteNodeService().getActiveNodeInstances(document.getDocumentId());
-        //commented out because the final RouteNodeInstance is now not active when the doc goes final
-//        assertEquals("Wrong number of active nodes.", 1, nodeInstances.size());
-//        isAtWDF = false;
-//        for (Iterator iter = nodeInstances.iterator(); iter.hasNext();) {
-//            RouteNodeInstance nodeInstance = (RouteNodeInstance) iter.next();
-//            if (nodeInstance.getRouteNode().getRouteNodeName().equals(WORKFLOW_DOCUMENT_FINAL_NODE)) {
-//                isAtWDF = true;
-//            }
-//        }
-//        assertTrue("Not at WDF", isAtWDF);
-        
+        assertEquals("The doc is processed so no node instances should be active", 0, nodeInstances.size());
+
         document = WorkflowDocumentFactory.loadDocument(getPrincipalIdForName("temay"), document.getDocumentId());
         assertTrue("Should have request.", document.isAcknowledgeRequested());
         document.acknowledge("");
@@ -207,9 +193,9 @@ public class ParallelRoutingTest extends KEWTestCase {
         // should have generated a request to "bmcgough"
         document = WorkflowDocumentFactory.loadDocument(getPrincipalIdForName("bmcgough"), document.getDocumentId());
         assertTrue("Document should be enroute", document.isEnroute());
-        List actionRequests = KEWServiceLocator.getActionRequestService().findPendingByDoc(document.getDocumentId());
+        List<ActionRequestValue> actionRequests = KEWServiceLocator.getActionRequestService().findPendingByDoc(document.getDocumentId());
         assertEquals("Incorrect pending action requests.", 1, actionRequests.size());
-        ActionRequestValue bRequest = (ActionRequestValue)actionRequests.get(0);
+        ActionRequestValue bRequest = actionRequests.get(0);
         assertNotNull("Should have been routed through node instance.", bRequest.getNodeInstance());
         assertTrue(document.isApprovalRequested());
         
