@@ -15,62 +15,6 @@
  */
 package org.kuali.rice.krad.maintenance;
 
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang.StringUtils;
-import org.apache.ojb.broker.core.proxy.ProxyHelper;
-import org.kuali.rice.core.api.config.property.ConfigContext;
-import org.kuali.rice.core.api.util.RiceKeyConstants;
-import org.kuali.rice.kew.api.KewApiServiceLocator;
-import org.kuali.rice.kew.api.WorkflowDocument;
-import org.kuali.rice.kew.api.doctype.DocumentType;
-import org.kuali.rice.kew.framework.postprocessor.DocumentRouteStatusChange;
-import org.kuali.rice.kim.api.identity.Person;
-import org.kuali.rice.krad.bo.DocumentAttachment;
-import org.kuali.rice.krad.bo.DocumentHeader;
-import org.kuali.rice.krad.bo.GlobalBusinessObject;
-import org.kuali.rice.krad.bo.MultiDocumentAttachment;
-import org.kuali.rice.krad.bo.Note;
-import org.kuali.rice.krad.bo.PersistableAttachment;
-import org.kuali.rice.krad.bo.PersistableAttachmentList;
-import org.kuali.rice.krad.bo.PersistableBusinessObject;
-import org.kuali.rice.krad.datadictionary.DocumentEntry;
-import org.kuali.rice.krad.datadictionary.WorkflowAttributes;
-import org.kuali.rice.krad.datadictionary.WorkflowProperties;
-import org.kuali.rice.krad.document.DocumentBase;
-import org.kuali.rice.krad.document.SessionDocument;
-import org.kuali.rice.krad.exception.PessimisticLockingException;
-import org.kuali.rice.krad.exception.ValidationException;
-import org.kuali.rice.krad.rules.rule.event.KualiDocumentEvent;
-import org.kuali.rice.krad.rules.rule.event.SaveDocumentEvent;
-import org.kuali.rice.krad.service.DocumentDictionaryService;
-import org.kuali.rice.krad.service.DocumentHeaderService;
-import org.kuali.rice.krad.service.DocumentService;
-import org.kuali.rice.krad.service.KRADServiceLocator;
-import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
-import org.kuali.rice.krad.service.MaintenanceDocumentService;
-import org.kuali.rice.krad.util.GlobalVariables;
-import org.kuali.rice.krad.util.KRADConstants;
-import org.kuali.rice.krad.util.NoteType;
-import org.kuali.rice.krad.util.ObjectUtils;
-import org.kuali.rice.krad.util.documentserializer.PropertySerializabilityEvaluator;
-import org.w3c.dom.Document;
-import org.w3c.dom.Node;
-import org.w3c.dom.NodeList;
-import org.xml.sax.InputSource;
-import org.xml.sax.SAXException;
-
-import javax.persistence.CascadeType;
-import javax.persistence.Column;
-import javax.persistence.Entity;
-import javax.persistence.FetchType;
-import javax.persistence.JoinColumn;
-import javax.persistence.ManyToMany;
-import javax.persistence.ManyToOne;
-import javax.persistence.Table;
-import javax.persistence.Transient;
-import javax.xml.parsers.DocumentBuilder;
-import javax.xml.parsers.DocumentBuilderFactory;
-import javax.xml.parsers.ParserConfigurationException;
 import java.io.IOException;
 import java.io.StringReader;
 import java.util.ArrayList;
@@ -78,21 +22,83 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 
+import javax.persistence.CascadeType;
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.JoinColumn;
+import javax.persistence.Lob;
+import javax.persistence.ManyToOne;
+import javax.persistence.OneToMany;
+import javax.persistence.OneToOne;
+import javax.persistence.Table;
+import javax.persistence.Transient;
+import javax.persistence.UniqueConstraint;
+import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.parsers.ParserConfigurationException;
+
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.lang.StringUtils;
+import org.kuali.rice.core.api.config.property.ConfigContext;
+import org.kuali.rice.core.api.mo.common.GloballyUnique;
+import org.kuali.rice.kew.api.KewApiServiceLocator;
+import org.kuali.rice.kew.api.WorkflowDocument;
+import org.kuali.rice.kew.api.doctype.DocumentType;
+import org.kuali.rice.kew.framework.postprocessor.DocumentRouteStatusChange;
+import org.kuali.rice.kim.api.identity.Person;
+import org.kuali.rice.krad.bo.DocumentAttachment;
+import org.kuali.rice.krad.bo.DocumentHeader;
+import org.kuali.rice.krad.bo.MultiDocumentAttachment;
+import org.kuali.rice.krad.bo.Note;
+import org.kuali.rice.krad.bo.PersistableAttachment;
+import org.kuali.rice.krad.bo.PersistableAttachmentList;
+import org.kuali.rice.krad.data.KradDataServiceLocator;
+import org.kuali.rice.krad.datadictionary.DocumentEntry;
+import org.kuali.rice.krad.datadictionary.WorkflowAttributes;
+import org.kuali.rice.krad.datadictionary.WorkflowProperties;
+import org.kuali.rice.krad.document.DocumentBase;
+import org.kuali.rice.krad.document.SessionDocument;
+import org.kuali.rice.krad.exception.PessimisticLockingException;
+import org.kuali.rice.krad.exception.ValidationException;
+import org.kuali.rice.krad.rules.rule.event.DocumentEvent;
+import org.kuali.rice.krad.rules.rule.event.SaveDocumentEvent;
+import org.kuali.rice.krad.service.BusinessObjectSerializerService;
+import org.kuali.rice.krad.service.DocumentDictionaryService;
+import org.kuali.rice.krad.service.DocumentService;
+import org.kuali.rice.krad.service.KRADServiceLocator;
+import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
+import org.kuali.rice.krad.service.MaintenanceDocumentService;
+import org.kuali.rice.krad.util.GlobalVariables;
+import org.kuali.rice.krad.util.KRADConstants;
+import org.kuali.rice.krad.util.NoteType;
+import org.kuali.rice.krad.util.documentserializer.PropertySerializabilityEvaluator;
+import org.w3c.dom.Document;
+import org.w3c.dom.Node;
+import org.w3c.dom.NodeList;
+import org.xml.sax.InputSource;
+import org.xml.sax.SAXException;
+
+import com.thoughtworks.xstream.core.BaseException;
+
 /**
  * Document class for all maintenance documents which wraps the maintenance object in
  * a <code>Maintainable</code> that is also used for various callbacks
  *
  * <p>
- * The maintenance xml structure will be: <maintainableDocumentContents maintainableImplClass="className">
+ * The maintenance xml structure will be: {@code <maintainableDocumentContents maintainableImplClass="className">
  * <oldMaintainableObject>... </oldMaintainableObject> <newMaintainableObject>... </newMaintainableObject>
- * </maintainableDocumentContents> Maintenance Document
+ * </maintainableDocumentContents> Maintenance Document}
  * </p>
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
 @Entity
-@Table(name = "KRNS_MAINT_DOC_T")
+@Table(name = "KRNS_MAINT_DOC_T",uniqueConstraints= {
+        @UniqueConstraint(name="KRNS_MAINT_DOC_TC0",columnNames="OBJ_ID")
+})
 public class MaintenanceDocumentBase extends DocumentBase implements MaintenanceDocument, SessionDocument {
+    protected static final int SUB_OBJECT_MATERIALIZATION_DEPTH = 3;
     private static final long serialVersionUID = -505085142412593305L;
     private static final org.apache.log4j.Logger LOG = org.apache.log4j.Logger.getLogger(MaintenanceDocumentBase.class);
 
@@ -107,16 +113,16 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     @Transient
     private static transient MaintenanceDocumentService maintenanceDocumentService;
     @Transient
-    private static transient DocumentHeaderService documentHeaderService;
-    @Transient
     private static transient DocumentService documentService;
 
     @Transient
     protected Maintainable oldMaintainableObject;
+
     @Transient
     protected Maintainable newMaintainableObject;
 
-    @Column(name = "DOC_CNTNT", length = 4096)
+    @Lob
+    @Column(name = "DOC_CNTNT")
     protected String xmlDocumentContents;
     @Transient
     protected boolean fieldsClearedOnCopy;
@@ -129,13 +135,15 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     @Transient
     protected String attachmentCollectionName;
 
-    @ManyToOne(fetch = FetchType.LAZY,
-            cascade = {CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REMOVE}) @JoinColumn(name = "DOC_HDR_ID",
+    @OneToOne(fetch = FetchType.LAZY,
+            cascade = {CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REMOVE})
+    @JoinColumn(name = "DOC_HDR_ID",
             insertable = false, updatable = false)
     protected DocumentAttachment attachment;
 
-    @ManyToMany(fetch = FetchType.LAZY,
-            cascade = {CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REMOVE}) @JoinColumn(name = "DOC_HDR_ID",
+    @OneToMany(fetch = FetchType.LAZY,
+            cascade = {CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REMOVE})
+    @JoinColumn(name = "DOC_HDR_ID",
             insertable = false, updatable = false)
     protected List<MultiDocumentAttachment> attachments;
 
@@ -193,7 +201,11 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         String className = newMaintainableObject.getDataObject().getClass().getName();
         String truncatedClassName = className.substring(className.lastIndexOf('.') + 1);
         if (isOldDataObjectInDocument()) {
-            documentTitle = "Edit ";
+            if (KRADConstants.MAINTENANCE_COPY_ACTION.equals(oldMaintainableObject.getMaintenanceAction())) {
+                documentTitle = "Copy ";
+            } else {
+                documentTitle = "Edit ";
+            }
         } else {
             documentTitle = "New ";
         }
@@ -273,12 +285,20 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         // then populate those instances
         if (!StringUtils.isEmpty(xmlDocumentContents)) {
             DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+            /* KULRICE-12304:
+            * Modified this block to fetch the document type and use that
+            * document type to fetch the maintainable class from the document
+            * dictionary service.  This was necessary since the maintainable
+            * class which is persisted in the document content XML may be out
+            * of date if it changes across version updates.
+            */
             try {
                 DocumentBuilder builder = factory.newDocumentBuilder();
                 Document xmlDocument = builder.parse(new InputSource(new StringReader(xmlDocumentContents)));
-                String clazz = xmlDocument.getDocumentElement().getAttribute(MAINTAINABLE_IMPL_CLASS);
+                String documentTypeName = KewApiServiceLocator.getWorkflowDocumentService().getDocument(this.getDocumentNumber()).getDocumentTypeName();
+                Class<? extends Maintainable> maintainableClass = getDocumentDictionaryService().getMaintainableClass(documentTypeName);
                 if (isOldMaintainableInDocument(xmlDocument)) {
-                    oldMaintainableObject = (Maintainable) Class.forName(clazz).newInstance();
+                    oldMaintainableObject = (Maintainable) maintainableClass.newInstance();
                     Object dataObject = getDataObjectFromXML(OLD_MAINTAINABLE_TAG_NAME);
 
                     String oldMaintenanceAction = getMaintenanceAction(xmlDocument, OLD_MAINTAINABLE_TAG_NAME);
@@ -287,7 +307,7 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
                     oldMaintainableObject.setDataObject(dataObject);
                     oldMaintainableObject.setDataObjectClass(dataObject.getClass());
                 }
-                newMaintainableObject = (Maintainable) Class.forName(clazz).newInstance();
+                newMaintainableObject = (Maintainable) maintainableClass.newInstance();
                 Object bo = getDataObjectFromXML(NEW_MAINTAINABLE_TAG_NAME);
                 newMaintainableObject.setDataObject(bo);
                 newMaintainableObject.setDataObjectClass(bo.getClass());
@@ -314,9 +334,6 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
             } catch (IllegalAccessException e) {
                 LOG.error("Error while parsing document contents", e);
                 throw new RuntimeException("Could not load document contents from xml", e);
-            } catch (ClassNotFoundException e) {
-                LOG.error("Error while parsing document contents", e);
-                throw new RuntimeException("Could not load document contents from xml", e);
             }
         }
     }
@@ -385,36 +402,41 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     protected Object getDataObjectFromXML(String maintainableTagName) {
         String maintXml = StringUtils.substringBetween(xmlDocumentContents, "<" + maintainableTagName + ">",
                 "</" + maintainableTagName + ">");
+        /*KULRICE-12304*/
+        try {
+            boolean ignoreMissingFields = false;
+            String classAndDocTypeNames = ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.Config.IGNORE_MISSIONG_FIELDS_ON_DESERIALIZE);
+            if (!StringUtils.isEmpty(classAndDocTypeNames)) {
+                String classNameOnXML = StringUtils.substringBetween(xmlDocumentContents, "<" + maintainableTagName + "><", ">");
+                String classNamesNoSpaces = removeSpacesAround(classAndDocTypeNames);
+                List<String> classAndDocTypeNamesList = Arrays.asList(org.apache.commons.lang.StringUtils.split(classNamesNoSpaces, ","));
+                String originalDocTypeId = getDocumentHeader().getWorkflowDocument().getDocumentTypeId();
+                DocumentType docType = KewApiServiceLocator.getDocumentTypeService().getDocumentTypeById(originalDocTypeId);
 
-        boolean ignoreMissingFields = false;
-        String classAndDocTypeNames = ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.Config.IGNORE_MISSIONG_FIELDS_ON_DESERIALIZE);
-        if (!StringUtils.isEmpty(classAndDocTypeNames)) {
-            String classNameOnXML = StringUtils.substringBetween(xmlDocumentContents, "<" + maintainableTagName + "><", ">");
-            String classNamesNoSpaces = removeSpacesAround(classAndDocTypeNames);
-            List<String> classAndDocTypeNamesList = Arrays.asList(org.apache.commons.lang.StringUtils.split(classNamesNoSpaces, ","));
-            String originalDocTypeId = getDocumentHeader().getWorkflowDocument().getDocumentTypeId();
-            DocumentType docType = KewApiServiceLocator.getDocumentTypeService().getDocumentTypeById(originalDocTypeId);
-
-            while (docType != null && !ignoreMissingFields) {
-                for(String classNameOrDocTypeName : classAndDocTypeNamesList){
-                    if (docType.getName().equalsIgnoreCase(classNameOrDocTypeName) ||
-                        classNameOnXML.equalsIgnoreCase(classNameOrDocTypeName)) {
+                while (docType != null && !ignoreMissingFields) {
+                    for(String classNameOrDocTypeName : classAndDocTypeNamesList){
+                        if (docType.getName().equalsIgnoreCase(classNameOrDocTypeName) ||
+                                classNameOnXML.equalsIgnoreCase(classNameOrDocTypeName)) {
                             ignoreMissingFields = true;
                             break;
+                        }
+                    }
+                    if (!StringUtils.isEmpty(docType.getParentId())) {
+                        docType = KewApiServiceLocator.getDocumentTypeService().getDocumentTypeById(docType.getParentId());
+                    } else {
+                        docType = null;
                     }
                 }
-                if (!StringUtils.isEmpty(docType.getParentId())) {
-                    docType = KewApiServiceLocator.getDocumentTypeService().getDocumentTypeById(docType.getParentId());
-                } else {
-                    docType = null;
-                }
             }
-        }
-        if (!ignoreMissingFields) {
-            return KRADServiceLocator.getXmlObjectSerializerService().fromXml(maintXml);
-        } else {
-            return KRADServiceLocator.getXmlObjectSerializerIgnoreMissingFieldsService().fromXml(maintXml);
-        }
+            if (!ignoreMissingFields) {
+                return KRADServiceLocator.getXmlObjectSerializerService().fromXml(maintXml);
+            } else {
+                return KRADServiceLocator.getXmlObjectSerializerIgnoreMissingFieldsService().fromXml(maintXml);
+            }
+        }catch (BaseException e) {
+            String convertedXml = KRADServiceLocatorWeb.getMaintainableXMLConversionService().transformMaintainableXML(maintXml);
+            return KRADServiceLocator.getXmlObjectSerializerService().fromXml(convertedXml);
+        }/*KULRICE-12304*/
     }
 
     /**
@@ -480,12 +502,10 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
             Object oldBo = oldMaintainableObject.getDataObject();
 
             // hack to resolve XStream not dealing well with Proxies
-            if (oldBo instanceof PersistableBusinessObject) {
-                ObjectUtils.materializeAllSubObjects((PersistableBusinessObject) oldBo);
-            }
+            //KradDataServiceLocator.getDataObjectService().wrap(oldBo).materializeReferencedObjectsToDepth(SUB_OBJECT_MATERIALIZATION_DEPTH);
+            KRADServiceLocatorWeb.getLegacyDataAdapter().materializeAllSubObjects(oldBo);
 
-            docContentBuffer.append(
-                    KRADServiceLocator.getBusinessObjectSerializerService().serializeBusinessObjectToXml(oldBo));
+            docContentBuffer.append(getBusinessObjectSerializerService().serializeBusinessObjectToXml(oldBo));
 
             // add the maintainable's maintenanceAction
             docContentBuffer.append("<" + MAINTENANCE_ACTION_TAG_NAME + ">");
@@ -498,13 +518,10 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
 
         Object newBo = newMaintainableObject.getDataObject();
 
-        if (newBo instanceof PersistableBusinessObject) {
-            // hack to resolve XStream not dealing well with Proxies
-            ObjectUtils.materializeAllSubObjects((PersistableBusinessObject) newBo);
-        }
-
-        docContentBuffer.append(KRADServiceLocator.getBusinessObjectSerializerService().serializeBusinessObjectToXml(
-                newBo));
+        //KradDataServiceLocator.getDataObjectService().wrap(newBo).materializeReferencedObjectsToDepth(SUB_OBJECT_MATERIALIZATION_DEPTH);
+        KRADServiceLocatorWeb.getLegacyDataAdapter().materializeAllSubObjects(newBo);
+        
+        docContentBuffer.append(getBusinessObjectSerializerService().serializeBusinessObjectToXml(newBo));
 
         // add the maintainable's maintenanceAction
         docContentBuffer.append("<" + MAINTENANCE_ACTION_TAG_NAME + ">");
@@ -528,7 +545,7 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         // commit the changes to the Maintainable BusinessObject when it goes to Processed (ie, fully approved),
         // and also unlock it
         if (workflowDocument.isProcessed()) {
-            String documentNumber = getDocumentHeader().getDocumentNumber();
+            final String documentNumber = getDocumentHeader().getDocumentNumber();
             newMaintainableObject.setDocumentNumber(documentNumber);
 
             //Populate Attachment Property
@@ -732,10 +749,10 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     }
 
     /**
-     * @see DocumentBase#prepareForSave(org.kuali.rice.krad.rules.rule.event.KualiDocumentEvent)
+     * @see DocumentBase#prepareForSave(org.kuali.rice.krad.rules.rule.event.DocumentEvent)
      */
     @Override
-    public void prepareForSave(KualiDocumentEvent event) {
+    public void prepareForSave(DocumentEvent event) {
         super.prepareForSave(event);
         if (newMaintainableObject.getDataObject() instanceof PersistableAttachment) {
             populateDocumentAttachment();
@@ -763,80 +780,52 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
      * refreshReferenceObject is not returning null and the proxy cannot be materialized. So, this method exists to
      * properly handle the proxied attachment BO.  This is a hack and should be removed post JPA migration.
      */
+    @Deprecated
     protected void refreshAttachment() {
-        if (ObjectUtils.isNull(attachment)) {
-            this.refreshReferenceObject("attachment");
-            final boolean isProxy = attachment != null && ProxyHelper.isProxy(attachment);
-            if (isProxy && ProxyHelper.getRealObject(attachment) == null) {
-                attachment = null;
-            }
+        if (attachment == null) {
+            KradDataServiceLocator.getDataObjectService().wrap(this).fetchRelationship("attachment");
         }
     }
 
+    @Deprecated
     protected void refreshAttachmentList() {
-        if (ObjectUtils.isNull(attachments)) {
-            this.refreshReferenceObject("attachments");
-            final boolean isProxy = attachments != null && ProxyHelper.isProxy(attachments);
-            if (isProxy && ProxyHelper.getRealObject(attachments) == null) {
-                attachments = null;
-            }
+        if (attachments == null) {
+            KradDataServiceLocator.getDataObjectService().wrap(this).fetchRelationship("attachments");
         }
     }
 
-    public void populateAttachmentForBO() {
-        // TODO: need to convert this from using struts form file
+    @Deprecated
+    public void populateAttachmentForBO() { }
 
-    }
-
-    public void populateDocumentAttachment() {
-        // TODO: need to convert this from using struts form file
-        //        refreshAttachment();
-        //
-        //        if (fileAttachment != null && StringUtils.isNotEmpty(fileAttachment.getFileName())) {
-        //            //Populate DocumentAttachment BO
-        //            if (attachment == null) {
-        //                attachment = new DocumentAttachment();
-        //            }
-        //
-        //            byte[] fileContents;
-        //            try {
-        //                fileContents = fileAttachment.getFileData();
-        //                if (fileContents.length > 0) {
-        //                    attachment.setFileName(fileAttachment.getFileName());
-        //                    attachment.setContentType(fileAttachment.getContentType());
-        //                    attachment.setAttachmentContent(fileAttachment.getFileData());
-        //                    attachment.setDocumentNumber(getDocumentNumber());
-        //                }
-        //            } catch (FileNotFoundException e) {
-        //                LOG.error("Error while populating the Document Attachment", e);
-        //                throw new RuntimeException("Could not populate DocumentAttachment object", e);
-        //            } catch (IOException e) {
-        //                LOG.error("Error while populating the Document Attachment", e);
-        //                throw new RuntimeException("Could not populate DocumentAttachment object", e);
-        //            }
-        //        }
-        ////        else if(attachment != null) {
-        ////            //Attachment has been deleted - Need to delete the Attachment Reference Object
-        ////            deleteAttachment();
-        ////        }
-    }
+    @Deprecated
+    public void populateDocumentAttachment() { }
 
+    @Deprecated
     public void populateAttachmentListForBO() { }
 
+    @Deprecated
     public void populateAttachmentBeforeSave() { }
 
+    @Deprecated
     public void populateDocumentAttachmentList() { }
 
+    @Deprecated
     public void populateBoAttachmentListBeforeSave() { }
 
+    @Deprecated
     public void deleteDocumentAttachment() {
-        KRADServiceLocator.getBusinessObjectService().delete(attachment);
-        attachment = null;
+        if ( attachment != null ) {
+            KRADServiceLocatorWeb.getLegacyDataAdapter().delete(attachment);
+            attachment = null;
+        }
     }
 
+    @Deprecated
     public void deleteDocumentAttachmentList() {
         if (CollectionUtils.isNotEmpty(attachments)) {
-            KRADServiceLocator.getBusinessObjectService().delete(attachments);
+            for (MultiDocumentAttachment attachment : attachments) {
+                KRADServiceLocatorWeb.getLegacyDataAdapter().delete(attachment);
+            }
             attachments = null;
         }
     }
@@ -844,10 +833,10 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     /**
      * Explicitly NOT calling super here.  This is a complete override of the validation rules behavior.
      *
-     * @see org.kuali.rice.krad.document.DocumentBase#validateBusinessRules(org.kuali.rice.krad.rules.rule.event.KualiDocumentEvent)
+     * @see org.kuali.rice.krad.document.DocumentBase#validateBusinessRules(org.kuali.rice.krad.rules.rule.event.DocumentEvent)
      */
     @Override
-    public void validateBusinessRules(KualiDocumentEvent event) {
+    public void validateBusinessRules(DocumentEvent event) {
         if (GlobalVariables.getMessageMap().hasErrors()) {
             logErrors();
             throw new ValidationException("errors occured before business rule");
@@ -857,22 +846,9 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         checkForLockingDocument(true);
 
         // Make sure the business object's version number matches that of the databases copy.
-        if (newMaintainableObject != null) {
-            if (KRADServiceLocator.getPersistenceStructureService().isPersistable(
-                    newMaintainableObject.getDataObject().getClass())) {
-                PersistableBusinessObject pbObject = KRADServiceLocator.getBusinessObjectService().retrieve(
-                        (PersistableBusinessObject) newMaintainableObject.getDataObject());
-                Long pbObjectVerNbr = ObjectUtils.isNull(pbObject) ? null : pbObject.getVersionNumber();
-                Long newObjectVerNbr =
-                        ((PersistableBusinessObject) newMaintainableObject.getDataObject()).getVersionNumber();
 
-                if (pbObjectVerNbr != null && !(pbObjectVerNbr.equals(newObjectVerNbr))) {
-                    GlobalVariables.getMessageMap().putError(KRADConstants.GLOBAL_ERRORS,
-                            RiceKeyConstants.ERROR_VERSION_MISMATCH);
-                    throw new ValidationException(
-                            "Version mismatch between the local business object and the database business object");
-                }
-            }
+        if (newMaintainableObject != null) {
+            KRADServiceLocatorWeb.getLegacyDataAdapter().verifyVersionNumber(newMaintainableObject.getDataObject());
         }
 
         // perform validation against rules engine
@@ -900,7 +876,7 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
                 // that has not changed
             } else {
                 throw new ValidationException(
-                        "Unreported errors occured during business rule evaluation (rule developer needs to put meaningful error messages into global ErrorMap)");
+                        "Unreported errors occurred during business rule evaluation (rule developer needs to put meaningful error messages into global ErrorMap)");
             }
         }
 
@@ -915,24 +891,17 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
      * this needs to happen after the document itself is saved, to preserve consistency of the ver_nbr and in the case
      * of initial save, because this can't be saved until the document is saved initially
      *
-     * @see org.kuali.rice.krad.document.DocumentBase#postProcessSave(org.kuali.rice.krad.rules.rule.event.KualiDocumentEvent)
+     * @see org.kuali.rice.krad.document.DocumentBase#postProcessSave(org.kuali.rice.krad.rules.rule.event.DocumentEvent)
      */
     @Override
-    public void postProcessSave(KualiDocumentEvent event) {
-        if (getNewMaintainableObject().getDataObject() instanceof PersistableBusinessObject) {
-            PersistableBusinessObject bo = (PersistableBusinessObject) getNewMaintainableObject().getDataObject();
-            if (bo instanceof GlobalBusinessObject) {
-                KRADServiceLocator.getBusinessObjectService().save(bo);
-            }
-        }
-
+    public void postProcessSave(DocumentEvent event) {
         //currently only global documents could change the list of what they're affecting during routing,
         //so could restrict this to only happening with them, but who knows if that will change, so safest
         //to always do the delete and re-add...seems a bit inefficient though if nothing has changed, which is
         //most of the time...could also try to only add/update/delete what's changed, but this is easier
         if (!(event instanceof SaveDocumentEvent)) { //don't lock until they route
-            getMaintenanceDocumentService().deleteLocks(this.getDocumentNumber());
-            getMaintenanceDocumentService().storeLocks(this.getNewMaintainableObject().generateMaintenanceLocks());
+            getMaintenanceDocumentService().deleteLocks(MaintenanceDocumentBase.this.getDocumentNumber());
+            getMaintenanceDocumentService().storeLocks(MaintenanceDocumentBase.this.getNewMaintainableObject().generateMaintenanceLocks());
         }
     }
 
@@ -947,7 +916,7 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     /**
      * <p>The Note target for maintenance documents is determined by whether or not the underlying {@link Maintainable}
      * supports business object notes or not.  This is determined via a call to {@link
-     * Maintainable#isBoNotesEnabled()}.
+     * org.kuali.rice.krad.maintenance.Maintainable#isNotesEnabled()}.
      * The note target is then derived as follows: <p/> <ul> <li>If the {@link Maintainable} supports business object
      * notes, delegate to {@link #getDocumentDataObject()}. <li>Otherwise, delegate to the default implementation of
      * getNoteTarget on the superclass which will effectively return a reference to the {@link DocumentHeader}. </ul>
@@ -955,13 +924,13 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
      * @see org.kuali.rice.krad.document.Document#getNoteTarget()
      */
     @Override
-    public PersistableBusinessObject getNoteTarget() {
+    public GloballyUnique getNoteTarget() {
         if (getNewMaintainableObject() == null) {
             throw new IllegalStateException(
                     "Failed to acquire the note target.  The new maintainable object on this document is null.");
         }
-        if (getNewMaintainableObject().isNotesEnabled()) {
-            return (PersistableBusinessObject) getDocumentDataObject();
+        if (getNewMaintainableObject().isNotesEnabled() && getDocumentDataObject() instanceof GloballyUnique ) {
+            return (GloballyUnique) getDocumentDataObject();
         }
         return super.getNoteTarget();
     }
@@ -969,7 +938,7 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
     /**
      * The {@link NoteType} for maintenance documents is determined by whether or not the underlying {@link
      * Maintainable} supports business object notes or not.  This is determined via a call to {@link
-     * Maintainable#   isBoNotesEnabled()}.  The {@link NoteType} is then derived as follows: <p/> <ul> <li>If the
+     * Maintainable#isNotesEnabled()}.  The {@link NoteType} is then derived as follows: <p/> <ul> <li>If the
      * {@link
      * Maintainable} supports business object notes, return {@link NoteType#BUSINESS_OBJECT}. <li>Otherwise, delegate
      * to
@@ -1055,60 +1024,12 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         this.attachmentCollectionName = attachmentCollectionName;
     }
 
-    /**
-     * This overridden method is used to delete the {@link DocumentHeader} object due to the system not being able to
-     * manage the {@link DocumentHeader} object via mapping files
-     *
-     * @see org.kuali.rice.krad.bo.PersistableBusinessObjectBase#postRemove()
-     */
-    @Override
-    protected void postRemove() {
-        super.postRemove();
-        getDocumentHeaderService().deleteDocumentHeader(getDocumentHeader());
-    }
-
-    /**
-     * This overridden method is used to retrieve the {@link DocumentHeader} object due to the system not being able to
-     * manage the {@link DocumentHeader} object via mapping files
-     *
-     * @see org.kuali.rice.krad.bo.PersistableBusinessObjectBase#postLoad()
-     */
-    @Override
-    protected void postLoad() {
-        super.postLoad();
-        setDocumentHeader(getDocumentHeaderService().getDocumentHeaderById(getDocumentNumber()));
-    }
-
-    /**
-     * This overridden method is used to insert the {@link DocumentHeader} object due to the system not being able to
-     * manage the {@link DocumentHeader} object via mapping files
-     *
-     * @see org.kuali.rice.krad.bo.PersistableBusinessObjectBase#prePersist()
-     */
-    @Override
-    protected void prePersist() {
-        super.prePersist();
-        getDocumentHeaderService().saveDocumentHeader(getDocumentHeader());
-    }
-
-    /**
-     * This overridden method is used to save the {@link DocumentHeader} object due to the system not being able to
-     * manage the {@link DocumentHeader} object via mapping files
-     *
-     * @see org.kuali.rice.krad.bo.PersistableBusinessObjectBase#preUpdate()
-     */
-    @Override
-    protected void preUpdate() {
-        super.preUpdate();
-        getDocumentHeaderService().saveDocumentHeader(getDocumentHeader());
-    }
-
     /**
      * This method to check whether the document class implements SessionDocument
      *
      * TODO: move to KNS maintenance document base
      *
-     * @return
+     * @return true if the document is a session document
      */
     public boolean isSessionDocument() {
         return SessionDocument.class.isAssignableFrom(this.getClass());
@@ -1156,13 +1077,6 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         return maintenanceDocumentService;
     }
 
-    protected DocumentHeaderService getDocumentHeaderService() {
-        if (documentHeaderService == null) {
-            documentHeaderService = KRADServiceLocatorWeb.getDocumentHeaderService();
-        }
-        return documentHeaderService;
-    }
-
     protected DocumentService getDocumentService() {
         if (documentService == null) {
             documentService = KRADServiceLocatorWeb.getDocumentService();
@@ -1170,6 +1084,13 @@ public class MaintenanceDocumentBase extends DocumentBase implements Maintenance
         return documentService;
     }
 
+    /**
+     * @return the service used for serializing maintained business / data objects
+     */
+    protected BusinessObjectSerializerService getBusinessObjectSerializerService() {
+        return KRADServiceLocator.getDataObjectSerializerService();
+    }
+
     //for issue KULRice3070
     protected boolean checkAllowsRecordDeletion() {
         Boolean allowsRecordDeletion = KRADServiceLocatorWeb.getDocumentDictionaryService().getAllowsRecordDeletion(
